@@ -36,7 +36,7 @@ from __future__ import unicode_literals
 
 # Will be parsed by setup.py to determine package metadata
 __author__ = 'Stefan Kögl <stefan@skoegl.net>'
-__version__ = '1.3'
+__version__ = '1.4'
 __website__ = 'https://github.com/stefankoegl/python-json-pointer'
 __license__ = 'Modified BSD License'
 
@@ -255,7 +255,7 @@ class JsonPointer(object):
         """
         parts = [part.replace('~', '~0') for part in self.parts]
         parts = [part.replace('/', '~1') for part in parts]
-        return '/' + '/'.join(parts)
+        return ''.join('/' + part for part in parts)
 
     def __eq__(self, other):
         """ compares a pointer to another object
@@ -283,7 +283,7 @@ class JsonPointer(object):
         parts = [str(part) for part in parts]
         parts = [part.replace('~', '~0') for part in parts]
         parts = [part.replace('/', '~1') for part in parts]
-        ptr = cls('/' + '/'.join(parts))
+        ptr = cls(''.join('/' + part for part in parts))
         return ptr
 
 
